@@ -19,23 +19,33 @@
 usage: cb-ctl -h | --help
        cb-ctl --build-package-local --dist=<name>
            [--clean]
+           [--debug]
        cb-ctl --build-package=<package> --project-path=<path> --arch=<name> --dist=<name> --runner-group=<name>
+           [--debug]
        cb-ctl --build-image-local --selection=<name>
+           [--debug]
        cb-ctl --build-image=<image> --project-path=<path> --arch=<name> --runner-group=<name> --selection=<name>
+           [--debug]
        cb-ctl --build-dependencies=<package│image> --project-path=<path> --arch=<name> (--dist=<name>|--selection=<name>)
            [--timeout=<time_sec>]
+           [--debug]
        cb-ctl --build-dependencies-local --arch=<name> (--dist=<name>|--selection=<name>)
+           [--debug]
        cb-ctl --build-log=<package│image> --project-path=<path> --arch=<name> (--dist=<name>|--selection=<name>)
            [--keep-open]
            [--timeout=<time_sec>]
+           [--debug]
        cb-ctl --build-info=<package│image> --project-path=<path> --arch=<name> (--dist=<name>|--selection=<name>)
            [--timeout=<time_sec>]
+           [--debug]
        cb-ctl --get-binaries=<package│image> --project-path=<path> --arch=<name> --target-dir=<dir> (--dist=<name>|--selection=<name>)
            [--timeout=<time_sec>]
+           [--debug]
        cb-ctl --watch
            [--filter-request-id=<uuid>]
            [--filter-service-name=<name>]
            [--timeout=<time_sec>]
+           [--debug]
 
 options:
     --build-package=<package>
@@ -169,10 +179,7 @@ from kiwi.privileges import Privileges
 from kiwi.path import Path
 
 kiwi_log = logging.getLogger('kiwi')
-kiwi_log.setLevel(logging.INFO)
-
 log = logging.getLogger('cloud_builder')
-log.setLevel(logging.INFO)
 
 
 @exception_handler
@@ -186,6 +193,11 @@ def main() -> None:
         options_first=True
     )
     default_timeout = 10
+
+    log_level = logging.DEBUG if args['--debug'] else logging.INFO
+    kiwi_log.setLevel(log_level)
+    log.setLevel(log_level)
+
     if args['--build-package']:
         build_package(
             get_broker(),
@@ -284,8 +296,17 @@ def main() -> None:
 
 
 def get_broker() -> Any:
+    broker_type = 'kafka'
+    config = get_config()
+    broker_config_file = Defaults.get_broker_config()
+    config_settings = config.get('settings')
+    log.debug(config_settings)
+    if config_settings:
+        if config_settings.get('use_control_plane_as_proxy') is True:
+            broker_type = 'kafka_proxy'
+            broker_config_file = ''
     return CBMessageBroker.new(
-        'kafka', config_file=Defaults.get_broker_config()
+        broker_type, config_file=broker_config_file, custom_args=config
     )
 
 
@@ -472,8 +493,8 @@ def fetch_binaries(
     )
     if info_response:
         runner_ip = info_response['source_ip']
-        ssh_user = config['runner']['ssh_user']
-        ssh_pkey_file = config['runner']['ssh_pkey_file']
+        ssh_user = config['cluster']['ssh_user']
+        ssh_pkey_file = config['cluster']['ssh_pkey_file']
         Path.create(target_dir)
         for binary in info_response['binary_packages']:
             log.debug(f'Fetching {binary} -> {target_dir}')
@@ -573,8 +594,8 @@ def _get_info_response_file(
     )
     if info_response:
         runner_ip = info_response['source_ip']
-        ssh_user = config['runner']['ssh_user']
-        ssh_pkey_file = config['runner']['ssh_pkey_file']
+        ssh_user = config['cluster']['ssh_user']
+        ssh_pkey_file = config['cluster']['ssh_pkey_file']
         ssh_runner = [
             'ssh', '-i', ssh_pkey_file,
             '-o', 'StrictHostKeyChecking=accept-new',
@@ -707,7 +728,7 @@ def _info_reader(
     :param Callable func:
         Callback method for response record
     """
-    stop_reading_at = config['runner'].get('count') or 0
+    stop_reading_at = config['cluster'].get('runner_count') or 0
     response_count = 0
     info_records = []
     try:
